@@ -1,12 +1,14 @@
 <?php
-/*
+/**
+ * Show admin page
+ *
  * This file is part of Zoph.
  *
  * Zoph is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * Zoph is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -14,24 +16,22 @@
  * You should have received a copy of the GNU General Public License
  * along with Zoph; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ *
+ * @package Zoph
+ * @author Jeroen Roos
  */
 
-    require_once("include.inc.php");
+require_once "include.inc.php";
 
-    if (!$user->is_admin()) {
-        redirect(add_sid("zoph.php"));
-    }
-    $title=translate("Adminpage");
-    require_once("header.inc.php");
-    require_once("admin.inc.php");
-    $adminpage=get_admin_array();
-?>
-        <h1>
-          <?php echo $title ?>
-        </h1>
-        <div class="main">
-            <?php echo get_admin_page($adminpage) ?>
-        </div>
-<?php
-    require_once("footer.inc.php");
+if (!$user->isAdmin()) {
+    redirect("zoph.php");
+}
+$title=translate("Adminpage");
+$adminpages=admin::getArray();
+
+$tpl=new template("admin", array(
+    "title" => $title,
+    "adminpages" => $adminpages
+));
+echo $tpl;
 ?>
