@@ -6,7 +6,7 @@
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * Zoph is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -26,27 +26,38 @@
  * Jason
  */
 function process_exif($image) {
-
     $exifdata = array();
+    $file=new file($image);
+    $mime=$file->getMime();
 
-    $exif = read_exif_data($image);
+    if ($mime == "image/jpeg") {
+        $exif = read_exif_data($image);
+    } else {
+        $exif = false;
+    }
 
     if ($exif === false) {
+        echo "<b>" . basename($image) . "</b>" . ": ";
         echo translate("No EXIF header found.") . "<br>\n";
+
+        // Set date and time to file date/time
+        list($exifdata["date"],$exifdata["time"])=
+            explode(" ",date("Y-m-d H:i:s", filemtime($image)));
+
         return $exifdata;
     }
 
-    if ($exif["DateTimeOriginal"]) {
+    if (isset($exif["DateTimeOriginal"])) {
         $datetime = $exif["DateTimeOriginal"];
     }
-    else if ($exif["DateTimeDigitized"]) {
+    else if (isset($exif["DateTimeDigitized"])) {
         $datetime = $exif["DateTimeDigitized"];
     }
-    else if ($exif["DateTime"]) {
+    else if (isset($exif["DateTime"])) {
         $datetime = $exif["DateTime"];
     }
 
-    if (!$datetime) {
+    if (!isset($datetime)) {
         $datetime = date ("Y-m-d H:i:s", filemtime($image));
     }
     list($date, $time) = explode(' ', $datetime);
@@ -55,11 +66,11 @@ function process_exif($image) {
     $exifdata["date"] = $date;
     $exifdata["time"] = $time;
 
-    if ($exif["Make"]) {
+    if (isset($exif["Make"])) {
         $exifdata["camera_make"] = ucwords(strtolower($exif["Make"]));
     }
 
-    if ($exif["Model"]) {
+    if (isset($exif["Model"])) {
         $exifdata["camera_model"] = ucwords(strtolower($exif["Model"]));
     }
 
@@ -78,32 +89,32 @@ function process_exif($image) {
         //$exifdata["flash_used"] = $exif["Flash"] ? "Yes" : "No";
 
         // Revamped to handled more expressive flash indications
-        $fYN="No";
+        $fYN="N";
 
         switch ($exif["Flash"]) {
 
         // Flash Not Fired
         case 16:
-        case 0: $fYN="No"; break;
+        case 0: $fYN="N"; break;
 
         // Flash Fired
         case 9:
-        default: $fYN="Yes"; break;
+        default: $fYN="Y"; break;
         }
 
         $exifdata["flash_used"] = $fYN;
     }
 
-    if ($exif["FocalLength"]) {
+    if (isset($exif["FocalLength"])) {
         list($a, $b) = explode('/', $exif["FocalLength"]);
-        if($b>0) {
+        if ($b>0) {
             $exifdata["focal_length"] = sprintf("%.1fmm", $a / $b);
         }
     }
-
-    if ($exif["ExposureTime"]) {
+    $exifdata["exposure"]="";
+    if (isset($exif["ExposureTime"])) {
         list($a, $b) = explode('/', $exif["ExposureTime"]);
-        if($b>0) {
+        if ($b>0) {
             $val = $a / $b;
             $exifdata["exposure"] = sprintf("%.3f s", $val);
             if ($val <= 0.5) {
@@ -112,7 +123,7 @@ function process_exif($image) {
         }
     }
 
-    if ($exif["ExposureProgram"]) {
+    if (isset($exif["ExposureProgram"])) {
         $ep = $exif["ExposureProgram"];
         switch ($ep) {
         case 2:
@@ -127,30 +138,30 @@ function process_exif($image) {
         }
     }
 
-    if ($exif["FNumber"]) {
+    if (isset($exif["FNumber"])) {
         list($a, $b) = explode('/', $exif["FNumber"]);
-        if($b>0) {
+        if ($b>0) {
             $exifdata["aperture"] = sprintf("f/%.1f", $a / $b);
-        } 
-    }
-    else if ($exif["ApertureValue"]) {
-        list($a, $b) = explode('/', $exif["ApertureValue"]);
-        if($b>0) {
-            $exifdata["aperture"] = sprintf("f/%.1f", $a / $b * log(2) * 0.5);
         }
     }
-    else if ($exif["MaxApertureValue"]) {
+    else if (isset($exif["ApertureValue"])) {
+        list($a, $b) = explode('/', $exif["ApertureValue"]);
+        if ($b>0) {
+            $exifdata["aperture"] = sprintf("f/%.1f", pow(2,($a / $b)/2));
+        }
+    }
+    else if (isset($exif["MaxApertureValue"])) {
         list($a, $b) = explode('/', $exif["MaxApertureValue"]);
-        if($b>0) {
-            $exifdata["aperture"] = sprintf("f/%.1f", $a / $b * log(2) * 0.5);
+        if ($b>0) {
+            $exifdata["aperture"] = sprintf("f/%.1f", pow(2,($a / $b)/2));
         }
     }
 
-    if ($exif["FocusDistance"]) {
+    if (isset($exif["FocusDistance"])) {
         $exifdata["focus_dist"] = $exif["FocusDistance"];
     }
 
-    if ($exif["MeteringMode"]) {
+    if (isset($exif["MeteringMode"])) {
         $mm = $exif["MeteringMode"];
         switch ($mm) {
         case 2:
@@ -165,7 +176,7 @@ function process_exif($image) {
         }
     }
 
-    if ($exif["ISOSpeedRatings"]) {
+    if (isset($exif["ISOSpeedRatings"])) {
         $a = $exif["ISOSpeedRatings"];
         if ($a < 50) { $a *= 200; }
         $exifdata["iso_equiv"] = $a;
@@ -182,9 +193,9 @@ function process_exif($image) {
     }
     */
 
-    if ($exif["CompressedBitsPerPixel"]) {
+    if (isset($exif["CompressedBitsPerPixel"])) {
         list($a, $b) = explode('/', $exif["CompressedBitsPerPixel"]);
-        if($b>0) {
+        if ($b>0) {
             $val = round($a / $b);
             switch ($val) {
             case 1:
@@ -200,10 +211,61 @@ function process_exif($image) {
         }
     }
 
-    if ($exif["Comment"]) {
+    if (isset($exif["Comment"])) {
         $exifdata["comment"] = $exif["Comment"];
     }
 
+    if (isset($exif["GPSLatitudeRef"]) && isset($exif["GPSLatitude"]) &&
+        isset($exif["GPSLongitudeRef"]) && isset($exif["GPSLongitude"])) {
+        $latarray=$exif["GPSLatitude"];
+
+        // This is an array that looks like this
+        // array(3) {
+        //            [0]=>string(5) "150/1"  (degrees)
+        //            [1]=>string(4) "47/1"   (minutes)
+        //            [2]=>string(8) "1239/100" (seconds)
+
+        $latdegarray=explode("/", $latarray[0]);
+        $latminarray=explode("/", $latarray[1]);
+        $latsecarray=explode("/", $latarray[2]);
+
+        $latdeg=$latdegarray[0] / $latdegarray[1];
+        $latmin=$latminarray[0] / $latminarray[1];
+        $latsec=$latsecarray[0] / $latsecarray[1];
+
+        $lat=$latdeg + ($latmin / 60) + ($latsec / 3600);
+
+        if ($exif["GPSLatitudeRef"] == "S") {
+            $lat = $lat * -1;
+        }
+        $exifdata["lat"]=$lat;
+
+        $lonarray=$exif["GPSLongitude"];
+
+        $londegarray=explode("/", $lonarray[0]);
+        $lonminarray=explode("/", $lonarray[1]);
+        $lonsecarray=explode("/", $lonarray[2]);
+
+        $londeg=$londegarray[0] / $londegarray[1];
+        $lonmin=$lonminarray[0] / $lonminarray[1];
+        $lonsec=$lonsecarray[0] / $lonsecarray[1];
+
+        $lon=$londeg + ($lonmin / 60) + ($lonsec / 3600);
+
+        if ($exif["GPSLongitudeRef"] == "W") {
+            $lon = $lon * -1;
+        }
+        $exifdata["lon"]=$lon;
+        /*
+        // No alt in db yet
+        if (isset($exif["GPSAltitude"])) {
+            $altarray=explode("/", $exif["GPSAltitude"]);
+            $alt=$altarray[0] / $altarray[1];
+            $exifdata["alt"]=$alt;
+        }
+        */
+    }
+
     return $exifdata;
 }
 
